<?php
// Own namespace
namespace Org\Mxchange\CoreFramework\Filesystem\Pointer;

// Import framework stuff
use Org\Mxchange\CoreFramework\Filesystem\FilePointer;
use Org\Mxchange\CoreFramework\Stream\Input\StreamableInput;

/**
 * An interface for (mostly) file input pointers.
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2022 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface InputPointer extends StreamableInput, FilePointer {
	/**
	 * Read data a file pointer
	 *
	 * @return	$data	Read data from file
	 */
	function readFromFile ();

	/**
	 * Reads a line, maximum 4096 Bytes from current file pointer
	 *
	 * @return	$data	Read data from file
	 */
	function readLine ();

	/**
	 * Reads given amount of bytes from file.
	 *
	 * @param	$bytes	Amount of bytes to read or whole line (only text files)
	 * @return	$data	Data read from file
	 * @throws	NullPointerException	If the file pointer instance
	 *									is not set by setFileObject()
	 * @throws	InvalidResourceException	If there is being set
	 */
	function read (int $bytes = 0);

}
