<?php
// Own namespace
namespace Org\Mxchange\CoreFramework\Result\Search;

// Import framework stuff
use Org\Mxchange\CoreFramework\Criteria\Local\LocalSearchCriteria;
use Org\Mxchange\CoreFramework\Database\Frontend\DatabaseFrontend;
use Org\Mxchange\CoreFramework\Generic\FrameworkInterface;

/**
 * An interface for searchable results
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2022 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface SearchableResult extends FrameworkInterface {
	/**
	 * Searches for an entry in the data result and returns it
	 *
	 * @param	$criteriaInstance	The criteria to look inside the data set
	 * @return	$result				Found result entry
	 */
	function searchEntry (LocalSearchCriteria $criteriaInstance);

	/**
	 * Solver for result index value with call-back method
	 *
	 * @param	$databaseColumn		Database column where the index might be found
	 * @para	$callBack			Call-back object for setting the index
	 * @return	void
	 */
	function solveResultIndex (string $databaseColumn, DatabaseFrontend $frontendInstance, array $callBack);

}
